bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.random
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.random